<?php
/*
Copyright 2001,2002,2003 Dashamir Hoxha, dashohoxha@users.sourceforge.net

This file is part of phpWebApp.

phpWebApp is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

phpWebApp is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with phpWebApp; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA  
*/


//constants of the paths in the application
define("WEBAPP_PATH",   UP_PATH."web_app/");

define("GRAPHICS",      "graphics/");
define("TPL_PATH",      "templates/");
define("WOBJ_PATH",     "webobjects/");

//define paths and URLs of the sample applications
define("SAMPLE_PATH",   UP_PATH."empty-sample/");
define("APP1_PATH",     UP_PATH."app1/");
define("APP2_PATH",     UP_PATH."app2/");
define("APP3_PATH",     UP_PATH."app3/");

define("SAMPLE_URL",    UP_URL."empty-sample/");
define("APP1_URL",      UP_URL."app1/");
define("APP2_URL",      UP_URL."app2/");
define("APP3_URL",      UP_URL."app3/");

define("HOME_URL", "http://phpwebapp.sourceforge.net/");
?>
